@@ -16,40 +16,50 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef __G_DIR_H__
+#define __G_DIR_H__
+
 #if !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
 #error "Only <glib.h> can be included directly."
 #endif
 
-#ifndef __G_DIR_H__
-#define __G_DIR_H__
-
 #include <glib/gerror.h>
 
+#ifdef G_OS_UNIX
+#include <dirent.h>
+#endif
+
 G_BEGIN_DECLS
 
 typedef struct _GDir GDir;
 
+GLIB_AVAILABLE_IN_ALL
 GDir    *                g_dir_open           (const gchar  *path,
 					       guint         flags,
 					       GError      **error);
+GLIB_AVAILABLE_IN_ALL
 const gchar *            g_dir_read_name      (GDir         *dir);
+GLIB_AVAILABLE_IN_ALL
 void                     g_dir_rewind         (GDir         *dir);
+GLIB_AVAILABLE_IN_ALL
 void                     g_dir_close          (GDir         *dir);
 
+#ifndef __GTK_DOC_IGNORE__
 #ifdef G_OS_WIN32
 #define g_dir_open      g_dir_open_utf8
 #define g_dir_read_name g_dir_read_name_utf8
 
+GLIB_AVAILABLE_IN_ALL
 GDir        *g_dir_open_utf8      (const gchar  *path,
                                    guint         flags,
                                    GError      **error);
+GLIB_AVAILABLE_IN_ALL
 const gchar *g_dir_read_name_utf8 (GDir         *dir);
 #endif /* G_OS_WIN32 */
+#endif /* __GTK_DOC_IGNORE__ */
 
 G_END_DECLS
 
